## Product details

WEHUSE Portable Shower Caddy Basket is made of durable mesh that allows for easy water drainage and fast drying time. This conveniently sized shower tote with canvas handles provides plenty of storage space with large center pocket and 7 surrounding pockets.

Fill with all the essentials, from shampoo, soap, conditioner, brushes, combs, razors, loofahs, and more - all in a handy, organized bath caddy tote.

The mesh shower caddy tote bag can fold flat for storage when not in use. Perfect for use in college dorms, locker rooms, gyms, swimming pools, the beach, even use during travel.

It is helpful wherever you are in.
It’s a perfect gift for your family, friends, kids, children and college students. Get it now.

[Superior Mesh Shower Caddy ] - After upgrading, our shower caddy basket is made of high quality mesh without peculiar smell and has 2 durable handles. Hanging shower caddy bag on the door, hook and shower head, the water will drain and the superior mesh can dry quickly.
[ Oxford Cloth Waterproof Zipper Inner Bag ] - Compared to other general mesh shower bag, our shower tote dorm caddy is specially designed with a strong key hook and a waterproof inner bag to store small items, such as cell phone, watches and keys. Keep your valuables safe and dry.
[ Extra Large 7 Pockets Mesh Shower Tote ]- We have also increased the size of the bathroom shower caddy to accommodate more toiletries and dorm room accessories. XL large size and utility. It has a 9.06 inch deep main storage compartment with 7 roomy outer pockets, deep enough to hold tall products and prevent them from falling off.
[ Portable Shower Caddy Basket with Double Handles ] - Double Oxford cloth handles have better load-bearing capacity than single handle, not easy to tear and does not hurt hands. Can be folded small for easy storage when not in use and easy to carry when traveling, camping, swimming, bathing or go to the gym. Great travel shower caddy for dorm and college.
[ Useful and Cute Black Shower Mesh Caddy ] - The shower caddy portable is perfect for organization and keeping the bathroom more tidy. It comes in handy when you have to go somewhere and will be great for college life! Awesome gift for your family and friends and even a good idea for baby shower gifts.
info:
We aim to show you accurate product information. Manufacturers, suppliers and others provide what you see here, and we have not verified it.  See our disclaimer
## Specifications

Bathtub & shower organizer type
Shower Caddies
Mount type
Corner Mount, Shower Door Mount, Rod Mount, Over-the-Door
Number of hooks
1
Material
Mesh, Oxford Cloth
More details
## Warranty

Warranty information
Please be aware that the warranty terms on items offered for sale by third party Marketplace sellers may differ from those displayed in this section (if any). To confirm warranty terms on an item offered for sale by a third party Marketplace seller, please use the 'Contact seller' feature on the third party Marketplace seller's information page and request the item's warranty terms prior to purchase.
